==> commitlint-plugin-jira-1.0.4.tgz: package/index.js <==
var message = require('@commitlint/message');
if (typeof message !== 'function') {
    message = message.default;
}
module.exports = {
  rules: {
    'subject-jira': (parsed, when) => {
      // get commit msg's scope and subject
      const { scope, subject } = parsed;
      // not set subject or type
      if (!subject) {
        return [true]
      }
      /** 
       * jira smart commit regex
       * match like this <ISSUE_KEY1> <ISSUE_KEY2> <ISSUE_KEY3> #comment content #time 5h 5m
       */
      const issueKeyRegex = '([A-Z]+-[0-9]+\\s)+'
      const commentRegex = '#comment\\s([^\\s])+';
      const hourRegex = '([1-9]\\d*|0)(\\.[1-9])?h';
      const minRegex = '[1-9]\\d*m';
      const timeRegex = `#time\\s((${hourRegex}\\s${minRegex})|(${minRegex})|(${hourRegex}))`;
      const transitionRegex = '(#(close|resolve|open)\\s)?'
      const jiraRegex = `^${issueKeyRegex}${transitionRegex}((${timeRegex}\\s([^\\s])+)|(${commentRegex}\\s${timeRegex})|(${commentRegex}))`

      const negated = when === 'never';
      const matchResult = new RegExp(jiraRegex).exec(subject.trim());
      //  get match result
      let hasRegexp = (matchResult === null || matchResult[0] !== subject.trim()) ? false : true;
      // scope is * pass the jira regex
      if (scope === '*') {
        hasRegexp = true;
      }
      return [
        negated ? !hasRegexp : hasRegexp,
        message(['subject', negated ? 'is perfect' : 'is not match,should like <ISSUE_KEY1> <ISSUE_KEY2> <ISSUE_KEY3> #comment content #time 5h 5m '])
      ];
    }
  }
};

==> commitlint-plugin-jira-1.0.5.tgz: package/index.js <==
var message = require('@commitlint/message');
if (typeof message !== 'function') {
    message = message.default;
}
module.exports = {
  rules: {
    'subject-jira': (parsed, when) => {
      // get commit msg's scope and subject
      const { scope, subject } = parsed;
      // not set subject or type
      if (!subject) {
        return [true]
      }
      /** 
       * jira smart commit regex
       * match like this <ISSUE_KEY1> <ISSUE_KEY2> <ISSUE_KEY3> #comment content #time 5h 5m
       */
      const issueKeyRegex = '([A-Z]+[0-9]*-[0-9]+\\s)+'
      const commentRegex = '#comment\\s([^\\s])+';
      const hourRegex = '([1-9]\\d*|0)(\\.[1-9])?h';
      const minRegex = '[1-9]\\d*m';
      const timeRegex = `#time\\s((${hourRegex}\\s${minRegex})|(${minRegex})|(${hourRegex}))`;
      const transitionRegex = '(#(close|resolve|open)\\s)?'
      const jiraRegex = `^${issueKeyRegex}${transitionRegex}((${timeRegex}\\s([^\\s])+)|(${commentRegex}\\s${timeRegex})|(${commentRegex}))`

      const negated = when === 'never';
      const matchResult = new RegExp(jiraRegex).exec(subject.trim());
      //  get match result
      let hasRegexp = (matchResult === null || matchResult[0] !== subject.trim()) ? false : true;
      // scope is * pass the jira regex
      if (scope === '*') {
        hasRegexp = true;
      }
      return [
        negated ? !hasRegexp : hasRegexp,
        message(['subject', negated ? 'is perfect' : 'is not match,should like <ISSUE_KEY1> <ISSUE_KEY2> <ISSUE_KEY3> #comment content #time 5h 5m '])
      ];
    }
  }
};
